@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: export_doodads.pl,v 3.0 2002/08/28 01:16:32 lachoy Exp $
+# $Id: export_doodads.pl,v 3.1 2003/07/15 12:18:28 lachoy Exp $
 
 # To use this, first edit My/Common.pm with your database information
 # and then run (mysql example)
@@ -8,8 +8,10 @@
 # $ mysql test < users_groups_mysql.sql
 # $ perl stock_user_group.pl
 # $ perl stock_doodad.pl
+# $ perl export_doodads.pl
 
-# Also, try changing the argument in new() from 'object' to 'xml'
+# As XML:
+# $ perl export_doodads.pl xml
 
 use strict;
 use SPOPS::Export;
@@ -19,7 +21,8 @@ require My::User;
 require My::Doodad;
 
 {
-    my $exporter = SPOPS::Export->new( 'object' );
+    my $type = shift @ARGV || 'object';
+    my $exporter = SPOPS::Export->new( $type );
     $exporter->object_class( 'My::Doodad' );
     print $exporter->run;
 }
